@@ -930,6 +930,13 @@ class StdComp(Runner):
                             type=str, nargs='*',
                             help='pairs of (key value) for template variables')
 
+    def postauto(self):
+        """ creates parser
+        """
+        self._parser.add_argument('-f', '--online-xml-file',
+                                  help="online.xml file",
+                                  dest="onlinexmlfile", default="")
+
     def run(self, options):
         """ the main program function
 
@@ -1149,6 +1156,11 @@ class Comp(Runner):
             default=False, dest="minimal",
             help="device name without first '0'")
 
+        parser.add_argument(
+            "-e", "--depends",
+            help="list of component dependencies separated by ','",
+            dest="depends", default="")
+
         parser.add_argument(
             'args', metavar='component_name',
             type=str, nargs='*',
@@ -1241,10 +1253,12 @@ class SECoPCP(Runner):
         parser.add_argument("-a", "--can-fail", action="store_true",
                             default=False, dest="canfail",
                             help="can fail strategy flag")
-        parser.add_argument("-q", "--strict", action="store_true",
-                            default=False, dest="strict",
-                            help="NeXus strict group types i.e. "
-                            "use NXcollection if not defined")
+        parser.add_argument("-q", "--dynamic", action="store_true",
+                            default=False, dest="dynamiclinks",
+                            help="create dynamic links")
+        parser.add_argument("--sample-nxdata", action="store_true",
+                            default=False, dest="samplenxdata",
+                            help="create NXdata in NXsample")
         parser.add_argument("-c", "--component",
                             help="component name" +
                             "secop component name",
@@ -1265,8 +1279,11 @@ class SECoPCP(Runner):
                             dest="timeout", default=0.001)
         parser.add_argument("-s", "--sample",
                             help="sample name",
-                            dest="samplename", default="")
-
+                            dest="samplename", default="sample")
+        parser.add_argument("-w", "--sample-environment",
+                            help="sample environment name",
+                            dest="sampleenvname",
+                            default="sample_environment")
         parser.add_argument("-k", "--links",
                             help="NXlog links of physical "
                             "quantities to sensors "
@@ -1290,11 +1307,11 @@ class SECoPCP(Runner):
         parser.add_argument(
             "-z", "--transformation-attributes", dest="transattrs",
             default='{"rotation_z":'
-            '{"transformation_type":"rotation","vector":[0,-1,0]}}',
+            '{"transformation_type":"rotation","vector":[0,1,0]}}',
             help=("a JSON dictionary with transformation parameters i.e, "
                   '"transformation_type", "vector", "depends_on".'
                   ' Default: {"rotation_z":'
-                  '{"transformation_type":"rotation","vector":[0,-1,0]}}'))
+                  '{"transformation_type":"rotation","vector":[0,1,0]}}'))
         parser.add_argument("-p", "--xml-package", dest="xmlpackage",
                             help="xml template package")
         parser.add_argument("-y", "--entryname", dest="entryname",
