@@ -27,7 +27,10 @@ import sys
 # import binascii
 import time
 # import threading
-import PyTango
+try:
+    import tango
+except Exception:
+    import PyTango as tango
 from os.path import expanduser
 # import json
 # from nxstools import nxscreate
@@ -79,10 +82,10 @@ class NXSCreateClientDSDBTest(
         while not found and cnt < 1000:
             try:
                 sys.stdout.write(".")
-                xmlc = PyTango.DeviceProxy(
+                xmlc = tango.DeviceProxy(
                     self._sv.new_device_info_writer.name)
                 time.sleep(0.01)
-                if xmlc.state() == PyTango.DevState.ON:
+                if xmlc.state() == tango.DevState.ON:
                     found = True
                 found = True
             except Exception as e:
@@ -98,7 +101,7 @@ class NXSCreateClientDSDBTest(
                 "Cannot connect to %s"
                 % self._sv.new_device_info_writer.name)
 
-        if xmlc.state() == PyTango.DevState.ON:
+        if xmlc.state() == tango.DevState.ON:
             xmlc.JSONSettings = args
             xmlc.Open()
         version = xmlc.version
@@ -107,16 +110,16 @@ class NXSCreateClientDSDBTest(
         self.version = ".".join(vv[0:3])
         self.label = ".".join(vv[3:-1])
 
-        self.assertEqual(xmlc.state(), PyTango.DevState.OPEN)
+        self.assertEqual(xmlc.state(), tango.DevState.OPEN)
         return xmlc
 
     # closes opens config server
     # \param xmlc XMLConfigurator instance
     def closeConfig(self):
-        self.assertEqual(self._proxy.state(), PyTango.DevState.OPEN)
+        self.assertEqual(self._proxy.state(), tango.DevState.OPEN)
 
         self._proxy.Close()
-        self.assertEqual(self._proxy.state(), PyTango.DevState.ON)
+        self.assertEqual(self._proxy.state(), tango.DevState.ON)
 
     # test starter
     # \brief Common set up
