@@ -25,7 +25,10 @@ import sys
 import random
 import struct
 import binascii
-import PyTango
+try:
+    import tango
+except Exception:
+    import PyTango as tango
 from nxstools import nxscreate
 
 
@@ -70,7 +73,7 @@ class NXSCreateCompareTest(unittest.TestCase):
                       '"read_default_file":"/etc/my.cnf", "use_unicode":true}'
 
         # home = expanduser("~")
-        db = PyTango.Database()
+        db = tango.Database()
         self.host = db.get_db_host().split(".")[0]
         self.port = db.get_db_port()
         self.directory = "."
