@@ -387,33 +387,15 @@ For more help:
                 en = f.open("nexus_logs")
                 self.assertTrue(en.is_valid)
                 self.assertEqual(en.name, "nexus_logs")
-                self.assertEqual(len(en.attributes), 1)
+                self.assertEqual(len(en.attributes), 0)
                 self.assertEqual(en.size, 1)
 
-                at = en.attributes["NX_class"]
-                self.assertTrue(at.is_valid)
-                self.assertTrue(hasattr(at.shape, "__iter__"))
-                self.assertEqual(len(at.shape), 0)
-                self.assertEqual(at.shape, ())
-                self.assertEqual(at.dtype, "string")
-                self.assertEqual(at.name, "NX_class")
-                self.assertEqual(at[...], "NXcollection")
-
                 ins = en.open("configuration")
                 self.assertTrue(ins.is_valid)
                 self.assertEqual(ins.name, "configuration")
-                self.assertEqual(len(ins.attributes), 1)
+                self.assertEqual(len(ins.attributes), 0)
                 self.assertEqual(ins.size, 1)
 
-                at = ins.attributes["NX_class"]
-                self.assertTrue(at.is_valid)
-                self.assertTrue(hasattr(at.shape, "__iter__"))
-                self.assertEqual(len(at.shape), 0)
-                self.assertEqual(at.shape, ())
-                self.assertEqual(at.dtype, "string")
-                self.assertEqual(at.name, "NX_class")
-                self.assertEqual(at[...], "NXcollection")
-
                 f.close()
 
             finally:
@@ -455,33 +437,15 @@ For more help:
                 en = f.open("nexus_logs")
                 self.assertTrue(en.is_valid)
                 self.assertEqual(en.name, "nexus_logs")
-                self.assertEqual(len(en.attributes), 1)
+                self.assertEqual(len(en.attributes), 0)
                 self.assertEqual(en.size, 1)
 
-                at = en.attributes["NX_class"]
-                self.assertTrue(at.is_valid)
-                self.assertTrue(hasattr(at.shape, "__iter__"))
-                self.assertEqual(len(at.shape), 0)
-                self.assertEqual(at.shape, ())
-                self.assertEqual(at.dtype, "string")
-                self.assertEqual(at.name, "NX_class")
-                self.assertEqual(at[...], "NXcollection")
-
                 ins = en.open("configuration")
                 self.assertTrue(ins.is_valid)
                 self.assertEqual(ins.name, "configuration")
-                self.assertEqual(len(ins.attributes), 1)
+                self.assertEqual(len(ins.attributes), 0)
                 self.assertEqual(ins.size, 1)
 
-                at = ins.attributes["NX_class"]
-                self.assertTrue(at.is_valid)
-                self.assertTrue(hasattr(at.shape, "__iter__"))
-                self.assertEqual(len(at.shape), 0)
-                self.assertEqual(at.shape, ())
-                self.assertEqual(at.dtype, "string")
-                self.assertEqual(at.name, "NX_class")
-                self.assertEqual(at[...], "NXcollection")
-
                 f.close()
 
             finally:
